k2plr
=====

Pythonic access to `K2 <http://kepler.nasa.gov/>`_ data.
This is a fork of Daniel Foreman-Mackey's `kplr <https://github.com/dfm/kplr>`_ package.

Read `the kplr documentation <http://dan.iel.fm/kplr>`_!
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. image:: http://img.shields.io/pypi/dm/kplr.svg?style=flat
        :target: https://pypi.python.org/pypi/kplr/
.. image:: http://img.shields.io/pypi/v/kplr.svg?style=flat
        :target: https://pypi.python.org/pypi/kplr/
.. image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
        :target: https://github.com/dfm/kplr/blob/master/LICENSE
